import { Construct } from 'constructs';
export declare function getPropDot(instance: unknown, path: string): unknown;
export declare function hasPropDot(instance: unknown, path: string): boolean;
/**
 * A referenceable record.
 *
 * If `attributes` is set, the references is a map of sort and can return an attribute value for a given key.
 */
export interface Reference {
    logicalId: string;
    ref: string;
    instance?: any;
    hasAtt(attribute: string): boolean;
    hasProp(property: string): boolean;
}
export declare class References {
    private _store;
    add(reference: Reference): void;
    get(logicalId: string): Reference | undefined;
}
export declare class SimpleReference implements Reference {
    readonly logicalId: string;
    constructor(logicalId: string);
    get ref(): string;
    hasAtt(_attribute: string): boolean;
    hasProp(_property: string): boolean;
}
export declare class InstanceReference extends SimpleReference {
    readonly instance: any;
    constructor(logicalId: string, instance: any);
}
export declare class ValueOnlyReference extends InstanceReference {
    get ref(): string;
    hasProp(property: string): any;
}
export declare class CfnResourceReference extends InstanceReference {
    hasAtt(_attribute: string): boolean;
}
export declare class ConstructReference extends InstanceReference {
    readonly instance: Construct;
    constructor(id: string, instance: Construct);
    private get defaultChild();
    get ref(): string;
    hasAtt(attribute: string): boolean;
    hasProp(property: string): boolean;
}
