import { TemplateExpression } from './expression';
import { TemplateHook } from './hooks';
import { TemplateMapping } from './mappings';
import { TemplateOutput } from './output';
import { TemplateParameter } from './parameters';
import { TemplateResource } from './resource';
import { TemplateRule } from './rules';
import { DependencyGraph } from '../private/toposort';
import { schema } from '../schema';
/**
 * A template describes the desired state of some infrastructure
 */
export declare class Template {
    template: schema.Template;
    static fromFile(fileName: string): Promise<Template>;
    static fromObject(template: object): Template;
    static empty(): Template;
    readonly description?: string;
    readonly templateFormatVersion?: string;
    readonly parameters: Map<string, TemplateParameter>;
    readonly resources: Map<string, TemplateResource>;
    readonly conditions: Map<string, TemplateExpression>;
    readonly mappings: Map<string, TemplateMapping>;
    readonly outputs: Map<string, TemplateOutput>;
    readonly transform: string[];
    readonly metadata: Map<string, unknown>;
    readonly rules: Map<string, TemplateRule>;
    readonly hooks: Map<string, TemplateHook>;
    constructor(template: schema.Template);
    resource(logicalId: string): TemplateResource;
    condition(logicalId: string): TemplateExpression;
    /**
     * Return a graph containing all dependencies in execution order
     *
     * This includes relations established both by property references, as
     * well as 'DependsOn' declarations.
     */
    resourceGraph(): DependencyGraph<TemplateResource>;
}
