import * as reflect from 'jsii-reflect';
import { InstanceMethodCallExpression, StaticMethodCallExpression } from './callables';
import { TypedTemplateExpression } from './expression';
import { TypeResolutionContext } from './resolve';
import { RetentionPolicy, TemplateResource } from '../parser/template';
import { ResourceTag } from '../parser/template/tags';
export type ResourceLike = CfnResource | CdkConstruct | CdkObject | LazyResource;
interface BaseResourceLike {
    readonly logicalId: string;
    readonly namespace?: string;
    readonly tags: ResourceTag[];
    readonly dependsOn: string[];
}
export interface CfnResource extends BaseResourceLike {
    readonly fqn: string;
    readonly type: 'resource';
    readonly cfnType: string;
    readonly props: TypedTemplateExpression;
    readonly creationPolicy?: TypedTemplateExpression;
    readonly deletionPolicy?: RetentionPolicy;
    readonly updateReplacePolicy?: RetentionPolicy;
    readonly updatePolicy?: TypedTemplateExpression;
    readonly metadata?: Record<string, unknown>;
}
export interface CdkConstruct extends BaseResourceLike {
    readonly fqn: string;
    readonly type: 'construct';
    readonly props: TypedTemplateExpression;
    readonly overrides: any;
}
export interface CdkObject extends BaseResourceLike {
    readonly fqn: string;
    readonly type: 'cdkObject';
    readonly props: TypedTemplateExpression;
}
export interface LazyResource extends BaseResourceLike {
    readonly type: 'lazyResource';
    readonly call: StaticMethodCallExpression | InstanceMethodCallExpression;
    readonly overrides: any;
}
export declare function isCdkConstructExpression(x: unknown): x is CdkConstruct;
export declare function resolveResourceLike(logicalId: string, resource: TemplateResource, ctx: TypeResolutionContext): ResourceLike;
export declare function isCfnResource(resource: TemplateResource): boolean;
export declare function isConstruct(type?: reflect.Type): type is reflect.ClassType;
export declare function isCdkObject(type?: reflect.Type): type is reflect.ClassType;
export {};
